@@ -72,7 +72,7 @@ new S3ToLambda(scope: Construct, id: string, props: S3ToLambdaProps);
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
 |lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of the lambda.Function created by the construct|
-|s3Bucket|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the s3.Bucket created by the construct|
+|s3Bucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of the s3.Bucket created by the construct|
 |s3LoggingBucket?|[`s3.Bucket`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-s3.Bucket.html)|Returns an instance of s3.Bucket created by the construct as the logging bucket for the primary bucket.|
 
 ## Default settings
@@ -171,7 +171,7 @@ class S3ToLambda(
 
     @builtins.property
     @jsii.member(jsii_name="s3Bucket")
-    def s3_bucket(self) -> aws_cdk.aws_s3.Bucket:
+    def s3_bucket(self) -> typing.Optional[aws_cdk.aws_s3.Bucket]:
         return jsii.get(self, "s3Bucket")
 
     @builtins.property
